@@ -35,14 +35,14 @@ fn build_with_artifacts_in_dir(path: &Path) {
     // Emit the cargo metadata lines to register libraries for linking.
     let cargo_metadata_path = path.join("cargo_metadata.txt");
     let metadata = std::fs::read_to_string(&cargo_metadata_path)
-        .expect(format!("failed to read {}", cargo_metadata_path.display()).as_str());
+        .unwrap_or_else(|_| panic!("failed to read {}", cargo_metadata_path.display()));
     println!("{}", metadata);
 }
 
 /// Build by calling a `pyoxidizer` executable to generate build artifacts.
 fn build_with_pyoxidizer_exe(exe: Option<String>, resolve_target: Option<&str>) {
     let pyoxidizer_exe = if let Some(path) = exe {
-        path.clone()
+        path
     } else {
         "pyoxidizer".to_string()
     };
@@ -87,7 +87,6 @@ fn build_with_pyoxidizer_native(resolve_target: Option<&str>) {
 
 fn main() {
     if env::var("CARGO_FEATURE_BUILD_MODE_STANDALONE").is_ok() {
-        return;
     } else if env::var("CARGO_FEATURE_BUILD_MODE_PYOXIDIZER_EXE").is_ok() {
         let target = if let Ok(target) = env::var("PYOXIDIZER_BUILD_TARGET") {
             Some(target)
