@@ -140,22 +140,20 @@ pub struct PythonConfig {
     pub verbose: i32,
 
     /// Bytecode for the importlib._bootstrap / _frozen_importlib module.
-    pub frozen_importlib_data: &'static [u8],
+    pub frozen_importlib_bytecode: &'static [u8],
 
     /// Bytecode for the importlib._bootstrap_external / _frozen_importlib_external module.
-    pub frozen_importlib_external_data: &'static [u8],
+    pub frozen_importlib_external_bytecode: &'static [u8],
 
-    /// Reference to raw Python modules data.
+    /// Reference to packed resources data.
     ///
-    /// The referenced data is produced as part of PyOxidizer packaging. This
-    /// likely comes from an include_bytes!(...) of a file generated by PyOxidizer.
-    pub py_modules_data: &'static [u8],
-
-    /// Reference to raw Python resources data.
+    /// The referenced data contains Python module data. It likely comes from an
+    /// `include_bytes!(...)` of a file generated by PyOxidizer.
     ///
-    /// The referenced data is produced as part of PyOxidizer packaging. This
-    /// likely comes from an include_bytes!(...) of a file generated by PyOxidizer.
-    pub py_resources_data: &'static [u8],
+    /// The format of the data is defined by the ``python-packed-resources``
+    /// crate. The data will be parsed as part of initializing the custom
+    /// meta path importer during interpreter initialization.
+    pub packed_resources: &'static [u8],
 
     /// Extra extension modules to make available to the interpreter.
     ///
@@ -198,3 +196,48 @@ pub struct PythonConfig {
     ///
     pub run: PythonRunMode,
 }
+
+impl Default for PythonConfig {
+    /// Create a new instance using defaults.
+    #[allow(unused)]
+    fn default() -> Self {
+        PythonConfig {
+            standard_io_encoding: None,
+            standard_io_errors: None,
+            opt_level: 0,
+            use_custom_importlib: false,
+            filesystem_importer: false,
+            sys_paths: vec![],
+            bytes_warning: 0,
+            import_site: false,
+            import_user_site: false,
+            ignore_python_env: true,
+            inspect: false,
+            interactive: false,
+            isolated: false,
+            legacy_windows_fs_encoding: false,
+            legacy_windows_stdio: false,
+            write_bytecode: false,
+            unbuffered_stdio: false,
+            parser_debug: false,
+            quiet: false,
+            use_hash_seed: false,
+            verbose: 0,
+            frozen_importlib_bytecode: &[],
+            frozen_importlib_external_bytecode: &[],
+            packed_resources: &[],
+            extra_extension_modules: vec![],
+            argvb: false,
+            sys_frozen: false,
+            sys_meipass: false,
+            raw_allocator: if cfg!(windows) {
+                PythonRawAllocator::System
+            } else {
+                PythonRawAllocator::Jemalloc
+            },
+            terminfo_resolution: TerminfoResolution::Dynamic,
+            write_modules_directory_env: None,
+            run: PythonRunMode::None,
+        }
+    }
+}
