@@ -4,14 +4,12 @@
 
 //! Manage an embedded Python interpreter.
 
-#[cfg(feature = "jemalloc-sys")]
-use super::pyalloc::make_raw_jemalloc_allocator;
 use {
     super::config::{PythonConfig, PythonRawAllocator, PythonRunMode, TerminfoResolution},
     super::importer::PyInit__pyoxidizer_importer,
     super::osutils::resolve_terminfo_dirs,
     super::pyalloc::{make_raw_rust_memory_allocator, RawAllocator},
-    super::pystr::{osstring_to_bytes, osstring_to_str, OwnedPyStr},
+    super::pystr::{osstr_to_pyobject, osstring_to_bytes, OwnedPyStr},
     cpython::exc::{SystemExit, ValueError},
     cpython::{
         GILGuard, NoArgs, ObjectProtocol, PyClone, PyDict, PyErr, PyList, PyModule, PyObject,
@@ -28,6 +26,9 @@ use {
     std::ptr::null,
 };
 
+#[cfg(feature = "jemalloc-sys")]
+use super::pyalloc::make_raw_jemalloc_allocator;
+
 pub const PYOXIDIZER_IMPORTER_NAME: &[u8] = b"_pyoxidizer_importer\0";
 
 const FROZEN_IMPORTLIB_NAME: &[u8] = b"_frozen_importlib\0";
@@ -48,13 +49,13 @@ fn make_custom_frozen_modules(config: &PythonConfig) -> [pyffi::_frozen; 3] {
     [
         pyffi::_frozen {
             name: FROZEN_IMPORTLIB_NAME.as_ptr() as *const i8,
-            code: config.frozen_importlib_data.as_ptr(),
-            size: config.frozen_importlib_data.len() as i32,
+            code: config.frozen_importlib_bytecode.as_ptr(),
+            size: config.frozen_importlib_bytecode.len() as i32,
         },
         pyffi::_frozen {
             name: FROZEN_IMPORTLIB_EXTERNAL_NAME.as_ptr() as *const i8,
-            code: config.frozen_importlib_external_data.as_ptr(),
-            size: config.frozen_importlib_external_data.len() as i32,
+            code: config.frozen_importlib_external_bytecode.as_ptr(),
+            size: config.frozen_importlib_external_bytecode.len() as i32,
         },
         pyffi::_frozen {
             name: null(),
@@ -217,13 +218,13 @@ impl<'a> MainPythonInterpreter<'a> {
         let origin = exe
             .parent()
             .ok_or_else(|| "unable to get exe parent")?
-            .display()
-            .to_string();
+            .to_path_buf();
+        let origin_string = origin.display().to_string();
 
         let sys_paths: Vec<String> = config
             .sys_paths
             .iter()
-            .map(|path| path.replace("$ORIGIN", &origin))
+            .map(|path| path.replace("$ORIGIN", &origin_string))
             .collect();
 
         // TODO should we call PyMem::SetupDebugHooks() if enabled?
@@ -271,10 +272,11 @@ impl<'a> MainPythonInterpreter<'a> {
         // that of the interpreter.
         // TODO specify lifetimes so the compiler validates this for us.
         let module_state = super::importer::InitModuleState {
+            current_exe: exe.clone(),
+            origin,
             register_filesystem_importer: self.config.filesystem_importer,
             sys_paths,
-            py_modules_data: config.py_modules_data,
-            py_resources_data: config.py_resources_data,
+            packed_resources: config.packed_resources,
         };
 
         if config.use_custom_importlib {
@@ -413,7 +415,7 @@ impl<'a> MainPythonInterpreter<'a> {
         // convert these to Python str instances using a platform-specific
         // mechanism.
         let args_objs = env::args_os()
-            .map(|os_arg| osstring_to_str(py, os_arg))
+            .map(|os_arg| osstr_to_pyobject(py, &os_arg, None))
             .collect::<Result<Vec<PyObject>, &'static str>>()?;
 
         // This will steal the pointer to the elements and mem::forget them.
@@ -473,7 +475,7 @@ impl<'a> MainPythonInterpreter<'a> {
 
         if config.sys_meipass {
             let meipass = b"_MEIPASS\0";
-            let value = PyString::new(py, &origin);
+            let value = PyString::new(py, &origin_string);
 
             match value.with_borrowed_ptr(py, |py_value| unsafe {
                 pyffi::PySys_SetObject(meipass.as_ptr() as *const i8, py_value)
